@@ -22,23 +22,19 @@ from minio import Minio
 
 class PresignedPutObjectTest(TestCase):
     def test_object_is_string(self):
-        client = Minio(endpoint='localhost:9000')
-        with self.assertRaises(TypeError):
-            client.presigned_put_object(bucket_name='hello', object_name=1234)
+        client = Minio('localhost:9000')
+        self.assertRaises(
+            TypeError, client.presigned_put_object, 'hello', 1234)
 
     def test_object_is_not_empty_string(self):
-        client = Minio(endpoint='localhost:9000')
-        with self.assertRaises(ValueError):
-            client.presigned_put_object(
-                bucket_name='hello',
-                object_name=' \t \n ',
-            )
+        client = Minio('localhost:9000')
+        self.assertRaises(
+            ValueError, client.presigned_put_object, 'hello', ' \t \n ')
 
     def test_expiry_limit(self):
-        client = Minio(endpoint='localhost:9000')
-        with self.assertRaises(ValueError):
-            client.presigned_put_object(
-                bucket_name='hello',
-                object_name='key',
-                expires=timedelta(days=8),
-            )
+        client = Minio('localhost:9000')
+        self.assertRaises(
+            ValueError,
+            client.presigned_put_object, 'hello', 'key',
+            expires=timedelta(days=8)
+        )
